MethodChannelAbyanPlugin class

An implementation of AbyanPluginPlatform that uses method channels.

Inheritance

Constructors

MethodChannelAbyanPlugin()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

callScanCardID(int documentType) Future<void>
override
closeJourney(String customerID) Future<void>
override
createJourney(String journeyType) Future<void>
override
fetchProducts() Future<void>
override
listenCardImages() → void
override
listenForEmptyFormInfo() → void
override
listenForErrors() Future<void>
override
listenForFormData() → void
override
listenForJourneyId() Future<void>
override
listenForProducts() → void
override
listenToCardData() → void
override
listenToCloseJourney() → void
override
listenToFaceIDData() → void
override
listenToKYCData() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scanYourFaceID() Future<void>
override
sendFormDataRequestToiOS(int productId) Future<void>
override
toString() String
A string representation of this object.
inherited
updateKYC(String kycField) Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited