AbyanPluginPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • AbyanPluginPlatform
Implementers

Constructors

AbyanPluginPlatform()
Constructs a SomePluginPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

callScanCardID(int documentType) Future<void>
closeJourney(String customerID) Future<void>
createJourney(String journeyType) Future<void>
fetchProducts() Future<void>
listenCardImages() → void
listenForEmptyFormInfo() → void
listenForErrors() Future<void>
listenForFormData() → void
listenForJourneyId() Future<void>
listenForProducts() → void
listenToCardData() → void
listenToCloseJourney() → void
listenToFaceIDData() → void
listenToKYCData() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scanYourFaceID() Future<void>
sendFormDataRequestToiOS(int productId) Future<void>
toString() String
A string representation of this object.
inherited
updateKYC(String kycField) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance AbyanPluginPlatform
The default instance of AbyanPluginPlatform to use.
getter/setter pair